@@ -181,10 +181,11 @@ void DownloadListsTask::Run()
 
     SetAction(L"Downloading RSS feed '"+Lum::Base::StringToWString(tags[tag])+L"'...");
 
-    if (curl_easy_perform(curl)!=CURLE_OK) {
-      std::cerr << "Cannot download file" << std::endl;
-      std::cerr << buffer << std::endl;
+    result=curl_easy_perform(curl);
+    if (result!=CURLE_OK) {
       error=curl_easy_strerror(result);
+      std::cerr << "Cannot download file '" <<url << "': " << error << std::endl;
+      std::cerr << buffer << std::endl;
       curl_easy_cleanup(curl);
       return;
     }
